@@ -19,9 +19,9 @@ class GeneralTaskModule(LightningModule):
 
     def on_train_start(self):
         self.metrics ={
-            'train': [m.to(self.device) for m in self.metrics['train'] if isinstance(m, Metric)],
-            'val': [m.to(self.device) for m in self.metrics['val'] if isinstance(m, Metric)],
-            'test': [m.to(self.device) for m in self.metrics['test'] if isinstance(m, Metric)]
+            'train': [m.to(self.device) if isinstance(m, Metric) else m for m in self.metrics['train']],
+            'val': [m.to(self.device) if isinstance(m, Metric) else m for m in self.metrics['val']],
+            'test': [m.to(self.device) if isinstance(m, Metric) else m for m in self.metrics['test']]
         }
 
     def on_test_start(self):
@@ -98,10 +98,18 @@ class GeneralTaskModule(LightningModule):
         if isinstance(inputs, (tuple, list)):
             data = inputs[0]
         else:
-            data = inptus
+            data = inputs
         if hasattr(data, 'shape'):
             return data.shape[0]
         elif hasattr(data, '__len__'):
             return len(data)
         else:
-            return 1
\ No newline at end of file
+            data_type = f'{type(data).__module__}.{type(data).__name__}'
+            if data_type == 'dgl.heterograph.DGLHeteroGraph':
+                return data.batch_size
+            elif data_type == 'torch_geometric.data.batch.DataBatch':
+                return data.num_graphs
+            elif data_type == 'torch_geometric.data.data.Data':
+                return 1
+            else:
+                return None
